__all__=['', 'CoInternetCreateSecurityManager', 'CoInternetIsFeatureEnabled', 'CoInternetSetFeatureEnabled', 'FEATURE_ADDON_MANAGEMENT', 'FEATURE_BEHAVIORS', 'FEATURE_DISABLE_MK_PROTOCOL', 'FEATURE_ENTRY_COUNT', 'FEATURE_GET_URL_DOM_FILEPATH_UNENCODED', 'FEATURE_HTTP_USERNAME_PASSWORD_DISABLE', 'FEATURE_LOCALMACHINE_LOCKDOWN', 'FEATURE_MIME_HANDLING', 'FEATURE_MIME_SNIFFING', 'FEATURE_OBJECT_CACHING', 'FEATURE_PROTOCOL_LOCKDOWN', 'FEATURE_RESTRICT_ACTIVEXINSTALL', 'FEATURE_RESTRICT_FILEDOWNLOAD', 'FEATURE_SAFE_BINDTOOBJECT', 'FEATURE_SECURITYBAND', 'FEATURE_UNC_SAVEDFILECHECK', 'FEATURE_VALIDATE_NAVIGATE_URL', 'FEATURE_WEBOC_POPUPMANAGEMENT', 'FEATURE_WINDOW_RESTRICTIONS', 'FEATURE_ZONE_ELEVATION', 'GET_FEATURE_FROM_PROCESS', 'GET_FEATURE_FROM_REGISTRY', 'GET_FEATURE_FROM_THREAD', 'GET_FEATURE_FROM_THREAD_INTERNET', 'GET_FEATURE_FROM_THREAD_INTRANET', 'GET_FEATURE_FROM_THREAD_LOCALMACHINE', 'GET_FEATURE_FROM_THREAD_RESTRICTED', 'GET_FEATURE_FROM_THREAD_TRUSTED', 'SET_FEATURE_IN_REGISTRY', 'SET_FEATURE_ON_PROCESS', 'SET_FEATURE_ON_THREAD', 'SET_FEATURE_ON_THREAD_INTERNET', 'SET_FEATURE_ON_THREAD_INTRANET', 'SET_FEATURE_ON_THREAD_LOCALMACHINE', 'SET_FEATURE_ON_THREAD_RESTRICTED', 'SET_FEATURE_ON_THREAD_TRUSTED']
import typing
import win32typing
"""A module, encapsulating the ActiveX Internet interfaces"""


def CoInternetCreateSecurityManager(reserved:'typing.Any') -> 'win32typing.PyIInternetSecurityManager':
    """
    None

Args:

      reserved(typing.Any):

Returns:

      win32typing.PyIInternetSecurityManager
        
    """
    pass
        

def CoInternetIsFeatureEnabled(flags:'typing.Any') -> 'typing.Any':
    """
    None

Args:

      flags(typing.Any):Return ValueReturns true for S_OK, False for other non-error hresults, or raises a com_error.

Returns:

      typing.Any:Return ValueReturns true for S_OK, False for other non-error hresults, or 

raises a com_error.

        
    """
    pass
        

def CoInternetSetFeatureEnabled(flags:'typing.Any',enable:'typing.Any') -> 'typing.Any':
    """
    None

Args:

      flags(typing.Any):
      enable(typing.Any):

Returns:

      typing.Any
        
    """
    pass
        
FEATURE_ADDON_MANAGEMENT = ...
FEATURE_BEHAVIORS = ...
FEATURE_DISABLE_MK_PROTOCOL = ...
FEATURE_ENTRY_COUNT = ...
FEATURE_GET_URL_DOM_FILEPATH_UNENCODED = ...
FEATURE_HTTP_USERNAME_PASSWORD_DISABLE = ...
FEATURE_LOCALMACHINE_LOCKDOWN = ...
FEATURE_MIME_HANDLING = ...
FEATURE_MIME_SNIFFING = ...
FEATURE_OBJECT_CACHING = ...
FEATURE_PROTOCOL_LOCKDOWN = ...
FEATURE_RESTRICT_ACTIVEXINSTALL = ...
FEATURE_RESTRICT_FILEDOWNLOAD = ...
FEATURE_SAFE_BINDTOOBJECT = ...
FEATURE_SECURITYBAND = ...
FEATURE_UNC_SAVEDFILECHECK = ...
FEATURE_VALIDATE_NAVIGATE_URL = ...
FEATURE_WEBOC_POPUPMANAGEMENT = ...
FEATURE_WINDOW_RESTRICTIONS = ...
FEATURE_ZONE_ELEVATION = ...
GET_FEATURE_FROM_PROCESS = ...
GET_FEATURE_FROM_REGISTRY = ...
GET_FEATURE_FROM_THREAD = ...
GET_FEATURE_FROM_THREAD_INTERNET = ...
GET_FEATURE_FROM_THREAD_INTRANET = ...
GET_FEATURE_FROM_THREAD_LOCALMACHINE = ...
GET_FEATURE_FROM_THREAD_RESTRICTED = ...
GET_FEATURE_FROM_THREAD_TRUSTED = ...
SET_FEATURE_IN_REGISTRY = ...
SET_FEATURE_ON_PROCESS = ...
SET_FEATURE_ON_THREAD = ...
SET_FEATURE_ON_THREAD_INTERNET = ...
SET_FEATURE_ON_THREAD_INTRANET = ...
SET_FEATURE_ON_THREAD_LOCALMACHINE = ...
SET_FEATURE_ON_THREAD_RESTRICTED = ...
SET_FEATURE_ON_THREAD_TRUSTED = ...
