__all__=['', 'APPBREAKFLAG_DEBUGGER_BLOCK', 'APPBREAKFLAG_DEBUGGER_HALT', 'APPBREAKFLAG_STEP', 'BREAKPOINT_DELETED', 'BREAKPOINT_DISABLED', 'BREAKPOINT_ENABLED', 'BREAKREASON_BREAKPOINT', 'BREAKREASON_DEBUGGER_BLOCK', 'BREAKREASON_DEBUGGER_HALT', 'BREAKREASON_ERROR', 'BREAKREASON_HOST_INITIATED', 'BREAKREASON_LANGUAGE_INITIATED', 'BREAKREASON_STEP', 'BREAKRESUMEACTION_ABORT', 'BREAKRESUMEACTION_CONTINUE', 'BREAKRESUMEACTION_STEP_INTO', 'BREAKRESUMEACTION_STEP_OUT', 'BREAKRESUMEACTION_STEP_OVER', 'CLSID_DefaultDebugSessionProvider', 'CLSID_MachineDebugManager', 'CLSID_ProcessDebugManager', 'DBGPROP_ATTRIB_ACCESS_FINAL', 'DBGPROP_ATTRIB_ACCESS_PRIVATE', 'DBGPROP_ATTRIB_ACCESS_PROTECTED', 'DBGPROP_ATTRIB_ACCESS_PUBLIC', 'DBGPROP_ATTRIB_HAS_EXTENDED_ATTRIBS', 'DBGPROP_ATTRIB_NO_ATTRIB', 'DBGPROP_ATTRIB_STORAGE_FIELD', 'DBGPROP_ATTRIB_STORAGE_GLOBAL', 'DBGPROP_ATTRIB_STORAGE_STATIC', 'DBGPROP_ATTRIB_STORAGE_VIRTUAL', 'DBGPROP_ATTRIB_TYPE_IS_CONSTANT', 'DBGPROP_ATTRIB_TYPE_IS_SYNCHRONIZED', 'DBGPROP_ATTRIB_TYPE_IS_VOLATILE', 'DBGPROP_ATTRIB_VALUE_IS_EXPANDABLE', 'DBGPROP_ATTRIB_VALUE_IS_INVALID', 'DBGPROP_ATTRIB_VALUE_READONLY', 'DBGPROP_INFO_ATTRIBUTES', 'DBGPROP_INFO_AUTOEXPAND', 'DBGPROP_INFO_DEBUGPROP', 'DBGPROP_INFO_FULLNAME', 'DBGPROP_INFO_NAME', 'DBGPROP_INFO_TYPE', 'DBGPROP_INFO_VALUE', 'DEBUG_TEXT_ALLOWBREAKPOINTS', 'DEBUG_TEXT_ISEXPRESSION', 'DOCUMENTNAMETYPE_APPNODE', 'DOCUMENTNAMETYPE_FILE_TAIL', 'DOCUMENTNAMETYPE_TITLE', 'DOCUMENTNAMETYPE_URL', 'ERRORRESUMEACTION_AbortCallAndReturnErrorToCaller', 'ERRORRESUMEACTION_ReexecuteErrorStatement', 'ERRORRESUMEACTION_SkipErrorStatement', 'EX_DBGPROP_INFO_DEBUGEXTPROP', 'EX_DBGPROP_INFO_ID', 'EX_DBGPROP_INFO_LOCKBYTES', 'EX_DBGPROP_INFO_NTYPE', 'EX_DBGPROP_INFO_NVALUE', 'SOURCETEXT_ATTR_COMMENT', 'SOURCETEXT_ATTR_FUNCTION_START', 'SOURCETEXT_ATTR_KEYWORD', 'SOURCETEXT_ATTR_NONSOURCE', 'SOURCETEXT_ATTR_NUMBER', 'SOURCETEXT_ATTR_OPERATOR', 'SOURCETEXT_ATTR_STRING', 'TEXT_DOC_ATTR_READONLY']
import typing
import win32typing
"""A module, encapsulating the ActiveX Debugging interfaces"""

APPBREAKFLAG_DEBUGGER_BLOCK = ...
APPBREAKFLAG_DEBUGGER_HALT = ...
APPBREAKFLAG_STEP = ...
BREAKPOINT_DELETED = ...
BREAKPOINT_DISABLED = ...
BREAKPOINT_ENABLED = ...
BREAKREASON_BREAKPOINT = ...
BREAKREASON_DEBUGGER_BLOCK = ...
BREAKREASON_DEBUGGER_HALT = ...
BREAKREASON_ERROR = ...
BREAKREASON_HOST_INITIATED = ...
BREAKREASON_LANGUAGE_INITIATED = ...
BREAKREASON_STEP = ...
BREAKRESUMEACTION_ABORT = ...
BREAKRESUMEACTION_CONTINUE = ...
BREAKRESUMEACTION_STEP_INTO = ...
BREAKRESUMEACTION_STEP_OUT = ...
BREAKRESUMEACTION_STEP_OVER = ...
CLSID_DefaultDebugSessionProvider = ...
CLSID_MachineDebugManager = ...
CLSID_ProcessDebugManager = ...
DBGPROP_ATTRIB_ACCESS_FINAL = ...
DBGPROP_ATTRIB_ACCESS_PRIVATE = ...
DBGPROP_ATTRIB_ACCESS_PROTECTED = ...
DBGPROP_ATTRIB_ACCESS_PUBLIC = ...
DBGPROP_ATTRIB_HAS_EXTENDED_ATTRIBS = ...
DBGPROP_ATTRIB_NO_ATTRIB = ...
DBGPROP_ATTRIB_STORAGE_FIELD = ...
DBGPROP_ATTRIB_STORAGE_GLOBAL = ...
DBGPROP_ATTRIB_STORAGE_STATIC = ...
DBGPROP_ATTRIB_STORAGE_VIRTUAL = ...
DBGPROP_ATTRIB_TYPE_IS_CONSTANT = ...
DBGPROP_ATTRIB_TYPE_IS_SYNCHRONIZED = ...
DBGPROP_ATTRIB_TYPE_IS_VOLATILE = ...
DBGPROP_ATTRIB_VALUE_IS_EXPANDABLE = ...
DBGPROP_ATTRIB_VALUE_IS_INVALID = ...
DBGPROP_ATTRIB_VALUE_READONLY = ...
DBGPROP_INFO_ATTRIBUTES = ...
DBGPROP_INFO_AUTOEXPAND = ...
DBGPROP_INFO_DEBUGPROP = ...
DBGPROP_INFO_FULLNAME = ...
DBGPROP_INFO_NAME = ...
DBGPROP_INFO_TYPE = ...
DBGPROP_INFO_VALUE = ...
DEBUG_TEXT_ALLOWBREAKPOINTS = ...
DEBUG_TEXT_ISEXPRESSION = ...
DOCUMENTNAMETYPE_APPNODE = ...
DOCUMENTNAMETYPE_FILE_TAIL = ...
DOCUMENTNAMETYPE_TITLE = ...
DOCUMENTNAMETYPE_URL = ...
ERRORRESUMEACTION_AbortCallAndReturnErrorToCaller = ...
ERRORRESUMEACTION_ReexecuteErrorStatement = ...
ERRORRESUMEACTION_SkipErrorStatement = ...
EX_DBGPROP_INFO_DEBUGEXTPROP = ...
EX_DBGPROP_INFO_ID = ...
EX_DBGPROP_INFO_LOCKBYTES = ...
EX_DBGPROP_INFO_NTYPE = ...
EX_DBGPROP_INFO_NVALUE = ...
SOURCETEXT_ATTR_COMMENT = ...
SOURCETEXT_ATTR_FUNCTION_START = ...
SOURCETEXT_ATTR_KEYWORD = ...
SOURCETEXT_ATTR_NONSOURCE = ...
SOURCETEXT_ATTR_NUMBER = ...
SOURCETEXT_ATTR_OPERATOR = ...
SOURCETEXT_ATTR_STRING = ...
TEXT_DOC_ATTR_READONLY = ...
